"""Top-level package for test_scraper_pypi."""

__author__ = """Kishore Sampath"""
__email__ = 'skishore2602.dev@gmail.com'
__version__ = '0.1.1'


from .test_scraper_pypi import TestScraperPypi

name = 'test_scraper_pypi'
__all__ = ['TestScraperPypi']