"""Main module."""


class TestScraperPypi:
    """Main class."""

    def main(self):
        """Main function."""
        return self.return_greet_message()

    def return_greet_message(self):
        """Return a greeting message."""
        message = "Hello World!"
        return message